<?php
/**
 * System Plugin for Joomla! - JMG Creative Buttons
 * @package     Joomla.Site
 * @subpackage  jmghighlighting
 * @copyright   Copyright (C) 2019 - 2027 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

/**
 * Class PlgSystemJmgCreativeButtons
 *
 * @since  1.0.0
 */
class PlgSystemJmgCreativeButtons extends JPlugin
{
	protected $autoloadLanguage = true;
	protected $app;
	
	public function onAfterRender(){
		// Don't run this plugin in the Admin
		if ($this->app->isClient('administrator')){
			return;
		}
		
		$body = $this->app->getBody();		
		$body = $this->replace($body);
		$this->app->setBody($body);
	}
	
	public function replace($text){
		
		preg_match_all('/{{jmg-button-\d+}}/', $text, $matches);
		
		foreach ($matches[0] as $matchIndex => $match){
			preg_match('/\d+/', $match, $m);
			$id = $m[0];
			$text = str_replace($match, $this->buildbutton($id), $text);
		}
		
		return $text;
	}
	
	public function buildbutton($id){
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('id AS id')
			->select('name AS name')
			->select('label AS label')
			->select('icon AS icon')
			->select('iconposition AS iconposition')
			->select('href AS href')
			->select('url AS url')
			->select('email AS email')
			->select('menuitemid AS menuitemid')
			->select('image AS image')
			->select('youtube AS youtube')
			->select('vimeo AS vimeo')
			->select('target AS target')
			->select('width AS width')
			->select('height AS height')
			->select('classes AS classes')
			->select('setimage AS setimage')
			->select('buttonimage AS buttonimage')
			->from('#__jmgcreativebuttons_buttons AS a')
			->where('a.id = '. $id)
			->where('a.state = 1');

		// Get the button settings.
		$db->setQuery($query);

		try
		{
			$settings = $db->loadObject();
		}
		catch (RuntimeException $e)
		{
			JFactory::getApplication()->enqueueMessage();
		}
		
		if(gettype($settings) == 'object'){
			
			
			if($settings->href == 'url'){
				$url = $settings->url;
			}
			if($settings->href == 'email'){
				$url = 'mailto:'.$settings->email;
			}
			if($settings->href == 'menuitem'){
				$url = JRoute::_('index.php?Itemid='.$settings->menuitemid);
			}
			if($settings->href == 'image'){
				$url = JURI::root().$settings->image;
			}
			if($settings->href == 'youtube'){
				$url = 'https://www.youtube.com/watch?v='.$settings->youtube;
			}
			if($settings->href == 'vimeo'){
				$url = 'https://vimeo.com/'.$settings->vimeo;
			}
			
			
			
			
			if($settings->target == 'modal'){
				
				$url = '#jmgModal'.$settings->id;
				$toggle = 'modal';
				$modal_params = array();
				$modal_params['title'] = $settings->label;
				$modal_params['remote'] = 'true';
				$modal_params['url'] = $url;
				$modal_params['footer'] = 'Powered By JMG Creative Buttons'; 
			    $modal_params['width'] = $settings->width;
				$modal_params['height'] = $settings->height;	
				$body = '<iframe style="border:none;" src="'.$url.'" id="info" class="iframe" name="info" seamless="" height="100%" width="100%" border="0"></iframe>';
				
				echo JHTML::_('bootstrap.renderModal', 'jmgModal'.$settings->id, $modal_params, $body);
				
			}
			else{
				
				$url = $url;
				$toggle = '';
				
			}
			
			$classes = '';
		
			foreach(json_decode($settings->classes,true) as $key => $value){
				$classes .= $value.' ';
			}
			
			if($settings->setimage == 1 && $settings->buttonimage != ''){
				$src = JURI::root().$settings->buttonimage;
				$button = '<a class="'.$classes.'" href="'.$url.'" target="'.$settings->target.'"  title="'.$settings->name.'" data-toggle="'.$toggle.'"><img src="'.$src.'" alt="'.$settings->label.'" /></a>';
			}
			else{
				$icon = ($settings->icon == '')? '' : ' <span class="icon-'.$settings->icon.'"> </span> ';
				$iconleft = ($settings->iconposition == 'left') ? $icon : '';
				$iconright = ($settings->iconposition == 'right') ? $icon : '';
				$button = '<a class="'.$classes.'" href="'.$url.'" target="'.$settings->target.'" title="'.$settings->name.'" data-toggle="'.$toggle.'">'.$iconleft.$settings->label.$iconright.'</a>';
			}
			
		}
		else{
			$button = '';	
		}
		
		return $button;
		
	}
}
